#
# spec file for package dkgpg
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           dkgpg
Version:        1.0.6
Release:        lp151.2.4
Summary:        Distributed Key Generation (DKG) and Threshold Cryptography for OpenPGP
License:        GPL-2.0+
Group:          Productivity/Security
Url:            https://www.nongnu.org/dkgpg/
Source:         https://download.savannah.gnu.org/releases/dkgpg/%{name}-%{version}.tar.gz
Source2:        https://download.savannah.gnu.org/releases/dkgpg/%{name}-%{version}.tar.gz.sig
Source3:        %{name}.keyring
BuildRequires:  gcc-c++
BuildRequires:  gmp-devel >= 4.2
BuildRequires:  libTMCG-devel >= 1.3.12
BuildRequires:  libgcrypt-devel >= 1.7
BuildRequires:  libgpg-error-devel >= 1.12

%description
The Distributed Privacy Guard (DKGPG) implements Distributed Key
Generation (DKG) and Threshold Cryptography for OpenPGP. The
generated public keys are RFC4880 compatible and can be used by e.g.
GnuPG. The main purpose of this software is distributing power among
multiple parties, eliminating single points of failure, and
increasing the difficulty of side-channel attacks on private key
material.

DKGPG consists of a number of command-line programs. The current implementation
is in experimental state and should NOT be used in production environments.

A shared private key and a common public key (currently only
DSA/ElGamal) are generated. Further interactive protocols perform the
private operations like decryption and signing of files, provided
that a previously defined threshold of parties/devices take part in
the distributed computation. Due to the interactiveness of the
protocols, a lot of messages between participating parties have to be
exchanged in a secure way. GNUnet's mesh-routed CADET srvice is used
to establish private and broadcast channels for this message
exchange. A TCP/IP-based service is included as an alternative. It
may be combined with torsocks and NAT of a local hidden service.

%prep
%setup -q

%build
%configure
make %{?_smp_mflags}

%install
%make_install

%files
%doc AUTHORS BUGS ChangeLog COPYING NEWS README TODO
%{_bindir}/dkg-*
%{_mandir}/man1/*%{ext_man}

%changelog
* Wed Mar 21 2018 kbabioch@suse.com
- Update to version 1.0.6:
  * dkg-keysign: added option "-k" (keyring with external keys)
  * dkg-encrypt: added option "-k" (keyring with external keys)
  * dkg-verify: added option "-k" (keyring with external keys)
  * dkg-keycheck: added option "-k" (keyring with external keys)
  * dkg-keycheck: added output of allowed external revocation keys
  * dkg-encrypt: added option "-s" to select appropriate subkey
  * dkg-encrypt: renamed option "-z" to "-t" for convenience
  * dkg-keysign: include only exportable signatures to output
  * check and set strict permissions (0600) for private key file
  * dkg-sign: added option "-U" (policy URI) and improved manpage
  * dkg-refresh: support generic verification and public key parsing
  * dkg-keysign: added options "-1" through "-3" (validation level)
  * dkg-keysign: added option "-u" (select user IDs) for CLT18
  * dkg-keysign: support generic verification and public key parsing
  * dkg-verify: support generic verification and public key parsing
  * dkg-encrypt: support generic encryption and public key parsing
  * dkg-generate: added no-modify key server preferences (0x80)
  * improved error handling for unrecognized OpenPGP (sub)packets
  * dkg-keycheck: changed semantics of option "-r" (reduce subkeys)
  * dkg-keycheck: uses new public-key block parser from LibTMCG
  * new default domain parameter set (CRS) due to LibTMCG changes
  * raised the requirement of libgcrypt version to >= 1.7.0
* Sat Feb 10 2018 jengelh@inai.de
- Trim/compact long description for size, and wrap at 70 cols.
* Thu Feb  8 2018 kbabioch@suse.com
- Update to version 1.0.5
  * added secure memory allocation from libgcrypt for some parts
  * dkg-verify: added options "-f" and "-t" for a validity period
  * added simple initalization procedure for memory locking
  * added basic check on signature strength in parse_signature()
  * added some basic checks on key strength in parse_public_key()
  * added check for revocation signatures in parse_public_key()
  * dkg-encrypt: added option "-z" for improved privacy (zero key ID)
  * dkg-verify: added validity checks on key and signature
  * dkg-keycheck: added ROCA vulnerability detector (Infineon RSALib)
  * added option "-U" for dkg-keysign (policy URI)
  * added option "-r" for dkg-keysign (revocation signature)
  * added option "-r" for dkg-keycheck (support for RSA keys)
  * added program dkg-keysign for creating certification signatures
  * dkg-decrypt: removed support for not integrity protected messages
  * dkg-keycheck: added test for small/same k in DSA signatures
  * dkg-refresh: added cache for very strong randomness
- Use https instead of http
* Mon Jan 15 2018 kbabioch@suse.com
- Initial packaging of version 1.0.4
